@@ -11,13 +11,14 @@ from abc import ABCMeta
 from itertools import count
 from typing import TYPE_CHECKING, cast, overload, Any, Dict, List, Iterator, \
     Optional, Union, Tuple, Type, MutableMapping, MutableSequence
-from elementpath import XPathContext, XPath2Parser
+from elementpath import XPathContext, XPath2Parser, build_node_tree, protocols
+from elementpath.etree import etree_tostring
 
-from .exceptions import XMLSchemaAttributeError, XMLSchemaTypeError, XMLSchemaValueError
-from .etree import ElementData, etree_tostring
+from .exceptions import XMLSchemaAttributeError, XMLSchemaKeyError, XMLSchemaTypeError, \
+    XMLSchemaValueError
 from .aliases import ElementType, XMLSourceType, NamespacesType, BaseXsdType, DecodeType
 from .helpers import get_namespace, get_prefixed_qname, local_name, raw_xml_encode
-from .converters import XMLSchemaConverter
+from .converters import ElementData, XMLSchemaConverter
 from .resources import XMLResource
 from . import validators
 
@@ -136,12 +137,28 @@ class DataElement(MutableSequence['DataElement']):
         """The string value of the data element."""
         return raw_xml_encode(self.value)
 
+    def _map_attribute_prefixed_name(self, name: str) -> str:
+        try:
+            prefix, _local_name = name.split(':')
+        except ValueError:
+            raise XMLSchemaValueError(f'{name!r} has a wrong format') from None
+        else:
+            try:
+                return '{%s}%s' % (self.nsmap[prefix], _local_name)
+            except KeyError:
+                msg = f'prefix {prefix!r} not found in {self} nsmap'
+                raise XMLSchemaKeyError(msg) from None
+
     def get(self, key: str, default: Any = None) -> Any:
         """Gets a data element attribute."""
+        if not key.startswith('{') and ':' in key:
+            key = self._map_attribute_prefixed_name(key)
         return self.attrib.get(key, default)
 
     def set(self, key: str, value: Any) -> None:
         """Sets a data element attribute."""
+        if not key.startswith('{') and ':' in key:
+            key = self._map_attribute_prefixed_name(key)
         self.attrib[key] = value
 
     @property
@@ -259,6 +276,10 @@ class DataElement(MutableSequence['DataElement']):
         root, errors = self.encode(validation='lax')
         return etree_tostring(root, self.nsmap, indent, max_lines, spaces_for_tab)
 
+    def _get_xpath_context(self) -> XPathContext:
+        xpath_root = build_node_tree(cast(protocols.ElementProtocol, self))
+        return XPathContext(xpath_root)
+
     def find(self, path: str,
              namespaces: Optional[NamespacesType] = None) -> Optional['DataElement']:
         """
@@ -269,7 +290,7 @@ class DataElement(MutableSequence['DataElement']):
         :return: the first matching data element or ``None`` if there is no match.
         """
         parser = XPath2Parser(namespaces, strict=False)
-        context = XPathContext(cast(Any, self))
+        context = self._get_xpath_context()
         result = next(parser.parse(path).select_results(context), None)
         return result if isinstance(result, DataElement) else None
 
@@ -284,11 +305,11 @@ class DataElement(MutableSequence['DataElement']):
         an empty list is returned if there is no match.
         """
         parser = XPath2Parser(namespaces, strict=False)
-        context = XPathContext(cast(Any, self))
+        context = self._get_xpath_context()
         results = parser.parse(path).get_results(context)
         if not isinstance(results, list):
             return []
-        return [e for e in results if isinstance(e, DataElement)]
+        return cast(List[DataElement], [e for e in results if isinstance(e, DataElement)])
 
     def iterfind(self, path: str,
                  namespaces: Optional[NamespacesType] = None) -> Iterator['DataElement']:
@@ -300,7 +321,7 @@ class DataElement(MutableSequence['DataElement']):
         :return: an iterable yielding all matching data elements in document order.
         """
         parser = XPath2Parser(namespaces, strict=False)
-        context = XPathContext(cast(Any, self))
+        context = self._get_xpath_context()
         results = parser.parse(path).select_results(context)
         yield from filter(lambda x: isinstance(x, DataElement), results)
 
@@ -396,16 +417,20 @@ class DataElementConverter(XMLSchemaConverter):
         obj.data_element_class = kwargs.get('data_element_class', self.data_element_class)
         return obj
 
-    def element_decode(self, data: ElementData, xsd_element: 'XsdElement',
-                       xsd_type: Optional[BaseXsdType] = None, level: int = 0) -> 'DataElement':
-        data_element = self.data_element_class(
+    def get_data_element(self, data: ElementData, xsd_element: 'XsdElement',
+                         xsd_type: Optional[BaseXsdType] = None) -> DataElement:
+        return self.data_element_class(
             tag=data.tag,
             value=data.text,
             nsmap=self.namespaces,
             xsd_element=xsd_element,
             xsd_type=xsd_type
         )
-        data_element.attrib.update((k, v) for k, v in self.map_attributes(data.attributes))
+
+    def element_decode(self, data: ElementData, xsd_element: 'XsdElement',
+                       xsd_type: Optional[BaseXsdType] = None, level: int = 0) -> 'DataElement':
+        data_element = self.get_data_element(data, xsd_element, xsd_type)
+        data_element.attrib.update(self.map_attributes(data.attributes))
 
         if (xsd_type or xsd_element.type).model_group is not None:
             for name, value, _ in self.map_content(data.content):
@@ -454,25 +479,12 @@ class DataBindingConverter(DataElementConverter):
     """
     __slots__ = ()
 
-    def element_decode(self, data: ElementData, xsd_element: 'XsdElement',
-                       xsd_type: Optional[BaseXsdType] = None, level: int = 0) -> 'DataElement':
+    def get_data_element(self, data: ElementData, xsd_element: 'XsdElement',
+                         xsd_type: Optional[BaseXsdType] = None) -> DataElement:
         cls = xsd_element.get_binding(self.data_element_class)
-        data_element = cls(
+        return cls(
             tag=data.tag,
             value=data.text,
             nsmap=self.namespaces,
             xsd_type=xsd_type
         )
-        data_element.attrib.update((k, v) for k, v in self.map_attributes(data.attributes))
-
-        if (xsd_type or xsd_element.type).model_group is not None:
-            for name, value, _ in self.map_content(data.content):
-                if not name.isdigit():
-                    data_element.append(value)
-                else:
-                    try:
-                        data_element[-1].tail = value
-                    except IndexError:
-                        data_element.value = value
-
-        return data_element
